@@ -10,7 +10,7 @@ import traceback
 
 from .scheduler import ThreadedScheduler, method
 from .utils import load_class_from_name
-from . import basemodule
+from .basemodule import Module
 
 
 class TaskManager(object):
@@ -156,7 +156,7 @@ class TaskManager(object):
                     self.log.info("Checking " + str(modname) + " Attribute " + str(attrname))
                     self.log.info(attr)
 
-                    if inspect.isclass(attr) and isModule(attr) and attr != basemodule.Module:
+                    if inspect.isclass(attr) and isModule(attr) and attr != Module:
                         # Get class name
                         fqcn = '.'.join([modname, attrname])
                         self.log.info("Module loaded : " + fqcn)
